*************
API Reference
*************

:mod:`pymunk` Package 
=====================

.. container:: submodule-index

    .. rubric:: Submodules

    .. toctree::
        :maxdepth: 1

        pymunk.autogeometry
        pymunk.batch
        pymunk.constraints
        pymunk.vec2d
        pymunk.matplotlib_util    
        pymunk.pygame_util
        pymunk.pyglet_util
        pymunk.tests
        pymunk.examples

.. container:: custom-index
 
    ..comment

.. rubric:: Pymunk

.. automodule:: pymunk
    :special-members: __init__, __matmul__
    
.. raw:: html

    <script type="text/javascript" src='_static/pymunk.js'></script>